@@ -1,13 +1,13 @@
 ;;; Compiled by f2cl version:
-;;; ("f2cl1.l,v 1.212 2009/01/08 18:58:49 rtoy Exp $"
+;;; ("f2cl1.l,v 1.215 2009/04/07 22:05:21 rtoy Exp $"
 ;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
 ;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
 ;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
-;;;  "f2cl5.l,v 1.199 2009/01/07 19:16:59 rtoy Exp $"
+;;;  "f2cl5.l,v 1.200 2009/01/19 02:38:17 rtoy Exp $"
 ;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
 ;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
 
-;;; Using Lisp CMU Common Lisp Snapshot 2008-12 (19E)
+;;; Using Lisp CMU Common Lisp 19f (19F)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -118,15 +118,9 @@
              (f2cl-lib:array-slice iwork f2cl-lib:integer4 (ndiml) ((1 *)))
              (f2cl-lib:array-slice iwork f2cl-lib:integer4 (ndimr) ((1 *)))
              smlsiz)
-          (declare (ignore var-3 var-4 var-5))
-          (when var-0
-            (setf n var-0))
-          (when var-1
-            (setf nlvl var-1))
-          (when var-2
-            (setf nd var-2))
-          (when var-6
-            (setf smlsiz var-6)))
+          (declare (ignore var-0 var-3 var-4 var-5 var-6))
+          (setf nlvl var-1)
+          (setf nd var-2))
         (setf ndb1 (the f2cl-lib:integer4 (truncate (+ nd 1) 2)))
         (f2cl-lib:fdo (i ndb1 (f2cl-lib:int-add i 1))
                       ((> i nd) nil)
@@ -523,8 +517,8 @@
        end_label
         (return
          (values nil
-                 smlsiz
-                 n
+                 nil
+                 nil
                  nil
                  nil
                  nil
@@ -569,10 +563,10 @@
                         (array double-float (*)) (array double-float (*))
                         (array fortran-to-lisp::integer4 (*))
                         (fortran-to-lisp::integer4))
-           :return-values '(nil fortran-to-lisp::smlsiz fortran-to-lisp::n nil
-                            nil nil nil nil nil nil nil nil nil nil nil nil nil
-                            nil nil nil nil nil nil fortran-to-lisp::info)
+           :return-values '(nil nil nil nil nil nil nil nil nil nil nil nil nil
+                            nil nil nil nil nil nil nil nil nil nil
+                            fortran-to-lisp::info)
            :calls '(fortran-to-lisp::dlasd6 fortran-to-lisp::dcopy
-                    fortran-to-lisp::dlaset fortran-to-lisp::dlasdq
-                    fortran-to-lisp::xerbla))))
+                    fortran-to-lisp::dlaset fortran-to-lisp::dlasdt
+                    fortran-to-lisp::dlasdq fortran-to-lisp::xerbla))))
 
