@@ -749,7 +749,7 @@
        (cond ((equal n 0) (merror "LORENTZ_GAUGE requires at least one argument"))
 	     ((equal n 1) (lorentz (arg 1) nil))
 	     (t (lorentz (arg 1)
-			 ((lambda (l) (cond ((sloop for v in  l
+			 ((lambda (l) (cond ((loop for v in  l
 						     always (symbolp v)) l)
 					    (t (merror
 "Invalid tensor name(s) in argument to LORENTZ_GAUGE"))))
@@ -1195,7 +1195,7 @@
     )
 
     ;If g has derivative indices then F must be constant in order to contract it
-    (and e (not (mget (caar f) '$constant)) (return nil))
+    (and e (not (kindp (caar f) '$constant)) (return nil))
 
     ;Contraction property of f is a list of (a.b)'s
     (cond
@@ -1562,7 +1562,7 @@
 	     ((and (alike1 e x) (not (and (rpobj e) (rpobj x)))) 1.)
 	     ((or (atom e) (member 'array (cdar e) :test #'eq))
 	      (chainrule1 e x))
-	     ((mget (caar e) '$constant) 0.)                    ;New line added
+	     ((kindp (caar e) '$constant) 0.)                    ;New line added
 	     ((eq (caar e) 'mrat) (ratdx e x))
 	     ((eq (caar e) 'mplus)
 	      (simplus (cons '(mplus) (sdiffmap (cdr e) x))
@@ -2192,7 +2192,9 @@
     (list (if (pzerop u) 0 (mul2 u (maxima-substitute (cadddr e) y (car e))))
       (if (pzerop v) 0 (mul3 v (maxima-substitute (caddr e) y (car e)) -1)))))
 
-(defun idiff%deriv (e) (let (derivflag) (simplifya (cons '(%idiff) e) t)))
+(defun idiff%deriv (e)
+  (declare (special derivflag))
+  (let (derivflag) (simplifya (cons '(%idiff) e) t)))
 
 (defun ideriv (e)
   (prog (exp z count)
@@ -2292,7 +2294,7 @@
 ;;	      (ichainrule e x))
 ;;        (idiff%deriv (list e x 1)))
           0)
-	     ((mget (caar e) '$constant) 0.)                    ;New line added
+	     ((kindp (caar e) '$constant) 0.)                    ;New line added
 	     ((eq (caar e) 'mrat) (ratdx e x))
 	     ((eq (caar e) 'mplus)
 	      (simplus (cons '(mplus) (idiffmap (cdr e) x))
@@ -2567,7 +2569,7 @@
        (prog (l)          ;objects by zero if they have no derivative indices.
 	     (cond ((< n 2) (merror "FLUSH takes at least 2 arguments"))
 		   ((not
-		      (sloop for v in (setq l (listify (f- 1 n)))
+		      (loop for v in (setq l (listify (f- 1 n)))
 			     always (symbolp v)))
 ;		      (apply 'and (mapcar 'symbolp
 ;					    (setq l (listify (f- 1 n))) ))
@@ -2578,7 +2580,7 @@ indexed objects")) (t (return (flush (arg 1) l t))))))
        (prog (l)          ;objects by zero if they have any derivative indices.
 	     (cond ((< n 2) (merror "FLUSH takes at least 2 arguments"))
 		   ((not
-		      (sloop for v in (setq l (listify (f- 1 n)))
+		      (loop for v in (setq l (listify (f- 1 n)))
 			     always (symbolp v))
 ;		      (apply 'and (mapcar 'symbolp
 ;					     (setq l (listify (f- 1 n)))))
@@ -2841,7 +2843,7 @@ indexed objects")) (t (return (flush (arg 1) l nil))))))
 (defun checkindex (e f)
   (cond ((and (atom e) (not (eq e f))) e)
 	((and (eq (caar e) 'mlist)
-	      (sloop for v in (cdr e) always (atom v))
+	      (loop for v in (cdr e) always (atom v))
 ;	      (apply 'and (mapcar 'atom (cdr e)))
 	      (not (member f e :test #'eq))) e)
 	(t (merror "Indices must be atoms different from the tensor name"))))
