@@ -11,21 +11,21 @@
 (in-package :maxima)
 
 ;;; Run-time support for translated code.
-;;; GJC: Experimental macsyma array lisp level support for translated
-;;; code.
+
+;;; GJC: Experimental macsyma array lisp level support for translated code.
 ;;; To quickly handle the array reference and setting syntax in macsyma,
 
-;;; In macsyma arrays go by an atomic name. Lists and matricies
+;;; In macsyma arrays go by an atomic name. Lists and matrices
 ;;; may be hacked with the array syntax, which is convient.
 
-;;;additions for handling arrays in value cell on cl --wfs
+;;; additions for handling arrays in value cell on cl --wfs
 
 (macsyma-module acall)
 
 (transl-module acall)
 
 (defmfun interval-error (fun low high)
-  (merror "Lower bound to ~:@M : ~M, not less than upper bound: ~M" fun low high))
+  (merror (intl:gettext "~@:M: lower bound ~M is greater than upper bound ~M") fun low high))
 
 (defmfun mfuncall (f &rest l)
   (cond ((functionp f)
@@ -45,7 +45,7 @@
        ((flonum fixnum t)
 	(apply #'aref aarray ind1 inds))
        (t
-	(merror "Bug: Non-handled array created. ~M" aarray))))
+	(merror (intl:gettext "MARRAYREF: encountered array ~M of unknown type.") aarray))))
     ((hash-table)
      (gethash (if inds (cons ind1 inds) inds) aarray))
     ((symbol)
@@ -73,7 +73,7 @@
 				     ((flonum) (= val flounbound))
 				     ((fixnum) (= val fixunbound))
 				     ((t) (eq val munbound))
-				     (t (merror "Bug: Array pointer of unknown type: ~S" ap)))
+				     (t (merror (intl:gettext "MARRAYREF: encountered array pointer ~S of unknown type.") ap)))
 				   (arrfind `((,aarray ,aarray) ,ind1 ,@inds))
 				   val)))
 			    ((setq ap (mget aarray 'array))
@@ -89,16 +89,16 @@
 		   (list-ref aarray (cons ind1 inds))
 		   `((mqapply aarray) ,aarray ,ind1 ,@inds))))
     (t
-     (merror "Bad object to reference as an array: ~M" aarray))))
+     (merror (intl:gettext "MARRAYREF: cannot retrieve an element of ~M") aarray))))
 
 (defmfun $arrayapply (ar inds)
   (unless ($listp inds)
-    (merror "The second arg to `arrayapply' must be a list."))
+    (merror (intl:gettext "arrayapply: second argument must be a list; found ~M") inds))
   (apply #'marrayref ar (cdr inds)))
 
 (defmfun $arraysetapply (ar inds val)
   (unless ($listp inds)
-    (merror "The second arg to `arrayapply' must be a list."))
+    (merror (intl:gettext "arraysetapply: second argument must be a list; found ~M") inds))
   (apply #'marrayset val ar (cdr inds)))
 
 (defmfun marrayset (val aarray &rest all-inds &aux ap (ind1 (first all-inds)) (inds (cdr all-inds)))
@@ -108,7 +108,7 @@
        ((fixnum flonum t)
 	(setf (apply #'aref aarray ind1 inds) val))
        (t
-	(merror "Bug: unhandled array type. ~M" aarray))))
+	(merror (intl:gettext "MARRAYSET: encountered array ~M of unknown type.") aarray))))
     ((hash-table)
      (setf (gethash (if (cdr all-inds)
 			(copy-list all-inds)
@@ -116,18 +116,16 @@
 		    aarray) val))
     ((symbol)
      (cond ((setq ap (get aarray 'array))
-	    (cond ((null inds)
-		   (store (funcall ap ind1) val))
-		  (t
-		   (setf (apply #'aref ap all-inds) val))))
+	    (if (null inds)
+		(setf (aref ap ind1) val)
+		(setf (apply #'aref ap all-inds) val)))
 	   ((setq ap (mget aarray 'array))
 	    ;; the macsyma ARRAY frob is NOT an array pointer, it
 	    ;; is a GENSYM with a lisp array property, don't
 	    ;; ask me why.
-	    (cond ((null inds)
-		   (store (funcall ap ind1) val))
-		  (t
-		   (setf (apply #'aref ap all-inds) val))))
+	    (if (null inds)
+		(setf (aref (symbol-array ap) ind1) val)
+		(setf (apply #'aref (symbol-array ap) all-inds) val)))
 	   ((setq ap (mget aarray 'hashar))
 	    (arrstore `((,aarray ,'array)
 			,@(mapcar #'(lambda (u) `((mquote simp) ,u)) all-inds))
@@ -140,9 +138,9 @@
 		      val))))
     (list (if (member (caar aarray) '(mlist $matrix) :test #'eq)
 	      (list-ref aarray all-inds t val)
-	      (merror "Bad use of `:' on~%~M" aarray)))
+	      (merror (intl:gettext "MARRAYSET: cannot assign to an element of ~M") aarray)))
     (t
-     (merror "Bad argument to set as an array.~%~M" aarray)))
+     (merror (intl:gettext "MARRAYSET: ~M is not an array.") aarray)))
   val)
 
 ;;; Note that all these have HEADERS on the list. The CAR of a list I
@@ -150,7 +148,7 @@
 
 (defun list-ref (l indexl &optional set-flag val)
   (cond ((atom l)
-	 (merror "Error-> tried to take part of an atom."))
+	 (merror (intl:gettext "LIST-REF: argument must be a list; found ~M") l))
 	((null (cdr indexl))
 	 (let ((n (car indexl)))
 	   (cond ((and (integerp n) (plusp n)
@@ -160,14 +158,14 @@
 				  (l (cdr l) (cdr l)))
 				 ((or (null l) (= j n))
 				  (cond ((null l)
-					 (merror "Improper index to list or matrix: ~M" n))
+					 (merror (intl:gettext "LIST-REF: invalid subscript: ~M") n))
 					(set-flag
 					 (rplaca l val))
 					(t
 					 (car l)))))))
 		    (if set-flag l ret)))
 		 (t
-		  (merror "Error-> ~M  bad part subscript." n)))))
+		  (merror (intl:gettext "LIST-REF: invalid subscript: ~M") n)))))
 	(set-flag
 	 (list-ref (list-ref l `(,(car indexl))) (cdr indexl) set-flag val)
 	 l)
@@ -228,25 +226,26 @@
 			(funcall (cadr ary) 2)
 			(length (cdr (arraydims (cadr ary)))))
 		    number-of-args)
-	   (merror "~:@M Array already defined with different dimensions" fnname)))
-	(t (mputprop fnname (setq ary (gensym)) 'hashar)
-	   (*array ary t 7)
-	   (store (funcall ary 0) 4)
-	   (store (funcall ary 1) 0)
-	   (store (funcall ary 2) number-of-args))))
+	   (merror (intl:gettext "INSURE-ARRAY-PROPS: array ~:@M already defined with different dimensions.") fnname)))
+	(t
+	 (setq ary (gensym))
+	 (mputprop fnname ary 'hashar)
+	 (setf (symbol-array ary) (make-array 7 :initial-element nil))
+	 (setf (aref (symbol-array ary) 0) 4)
+	 (setf (aref (symbol-array ary) 1) 0)
+	 (setf (aref (symbol-array ary) 2) number-of-args))))
 
 ;;; An entry point to $APPLY for translated code.
 
 (defmfun mapply-tr (fun list)
   (unless ($listp list)
-    (merror "Second arg to `apply' was not a list:~%~M" list))
+    (merror (intl:gettext "apply: second argument must be a list; found ~M") list))
   (mapply1 fun (cdr list) '|the first arg to a translated `apply'| list))
 
 (defmfun assign-check (var val)
   (let ((a (get var 'assign)))
     (if a (funcall a var val))))
 
-
 (declare-top (special maplp))
 
 (defmfun maplist_tr (fun  l1 &rest l)
@@ -334,7 +333,7 @@
     ((aarray)
      (case (array-element-type aarray)
        ((flonum) (aref aarray index))
-       (t (merror "Bad type of array to call for `float' value: ~M" aarray))))
+       (t (merror (intl:gettext "MARRAYREF1$: array must be an array of floats; found ~M") aarray))))
     (t
      (float (marrayref aarray index)))))
 
@@ -343,7 +342,7 @@
     ((aarray)
      (case (array-element-type aarray)
        ((flonum) (setf (aref aarray index) value))
-       (t (merror "Bad type of array to set `float' into: ~M" aarray))))
+       (t (merror (intl:gettext "MARRAYSET1$: array must be an array of floats; found ~M") aarray))))
     (t
      (float (marrayset value aarray index)))))
 
@@ -359,7 +358,7 @@
       (- x)
       (simplify (list '(mminus) x))))
 
-(defmfun retlist_tr n
-  (do ((j (1- n) (- j 2))
-       (l () (cons (list '(mequal simp) (arg j) (arg (1+ j))) l)))
+(defmfun retlist_tr (&rest args)
+  (do ((j (- (length args) 2) (- j 2))
+       (l () (cons (list '(mequal simp) (nth j args) (nth (1+ j) args)) l)))
       ((< j 0) (cons '(mlist simp) l))))
