@@ -40,7 +40,7 @@
 
 ;;note if $algepsilon is too large you may lose some roots.
 
-(defmvar $algdelta 1e-4 )
+(defmvar $algdelta 1e-5 )
 
 (defmvar $%rnum_list '((mlist))
   "Upon exit from ALGSYS this is bound to a list of the %RNUMS
@@ -110,7 +110,7 @@
     (setq solnlist (addmlist solnlist))
     (if numerflg
 	(let (($numer t) ($float t))
-	  (ssimplifya solnlist))
+	  (resimplify solnlist))
 	solnlist)))
 
 (defun condensesolnl (tempsolnl)
@@ -347,7 +347,7 @@
 
 (defun realonly (rootsl)
   (cond ((null rootsl) nil)
-	((freeof '$%i (car rootsl))
+	((equal 0 (sratsimp ($imagpart (car rootsl))))
 	 (nconc (list (car rootsl)) (realonly (cdr rootsl))))
 	(t (realonly (cdr rootsl)))))
 
