@@ -539,8 +539,10 @@ summation when necessary."
       (let (($simp nil))
         (setq summand ($substitute gensym-ind ind summand)))
       (setq foo (mbinding ((list gensym-ind) (list gensym-ind))
-			  (resimplify (meval summand))))
-      (let (($simp nil))
+                          (resimplify (meval summand))))
+      ;; At this point we do not switch off simplification to preserve
+      ;; the achieved simplification of the summand (DK 02/2010).
+      (let (($simp t))
 	(setq foo ($substitute ind gensym-ind foo)))
       (if (not (eq hi '$inf))
 	  (forget (list '(mgeqp) hi gensym-ind)))
@@ -582,11 +584,11 @@ summation when necessary."
 
     (setq acc
 	  (cond ((and (eq n '$inf) ($freeof i ex))
-		 (setq sgn ($asksign ex))
+		 (setq sgn (csign ex))
 		 (cond ((eq sgn '$pos) '$inf)
 		       ((eq sgn '$neg) '$minf)
 		       ((eq sgn '$zero) 0)
-		       (t `((%sum simp) ,ex ,lo ,hi))))
+		       (t `((%sum simp) ,ex ,i ,lo ,hi))))
 
 		((and (mbagp e) $listarith)
 		 (simplifya
@@ -672,7 +674,7 @@ summation when necessary."
             
             (t
 	     (setq ex (subst '%product '$product ex))
-	     `((%product) ,(subst k i ex) ,k ,lo ,hi))))
+	     `((%product simp) ,(subst k i ex) ,k ,lo ,hi))))
 
     ;; Hmm, this is curious... don't call existing product simplifications
     ;; if index range is infinite -- what's up with that??
