@@ -536,6 +536,10 @@
 
 ;;;; BOX
 
+;; Set the the property reversealias
+(defprop mbox $box reversealias)
+(defprop mlabox $box reversealias)
+
 (defmfun $dpart (&rest args)
   (mpart args nil t nil '$dpart))
 
