@@ -145,6 +145,17 @@
 (defun msize-atom (x l r)
   (prog (y)
      (cond ((numberp x) (setq y (exploden x)))
+	   ((stringp x)
+        (setq y (coerce x 'list))
+	    (do ((l y (cdr l))) ((null l))
+	      (cond
+            ((or (member (car l) '(#\" #\\) :test #'equal)
+                 (and (char< (car l) #\space)
+                      (not (char= (car l) #\return))))
+             (rplacd l (cons (car l) (cdr l)))
+             (rplaca l #\\)
+             (setq l (cdr l)))))
+        (setq y (cons #\" (nconc y (list #\")))))
 	   ((and (setq y (safe-get x 'reversealias))
 		 (not (and (member x $aliases :test #'eq) (get x 'noun))))
 	    (setq y (exploden (stripdollar y))))
@@ -152,16 +163,7 @@
        ((null (setq y (exploden x))))
        ((safe-get x 'noun) (return (msize-atom (get x 'noun) l r)))
 	   ((char= #\$ (car y)) (setq y (slash (cdr y))))
-	   ((stringp x)
-        (setq y (coerce x 'list))
-	    (do ((l y (cdr l))) ((null l))
-	      (cond ((or (member (car l) '(#\" #\\ #\; #\$) :test #'equal)
-			 (and (char< (car l) #\space)
-			      (not (char= (car l) #\return))))
-		     (rplacd l (cons (car l) (cdr l)))
-		     (rplaca l #\\) (setq l (cdr l)))))
-	    (setq y (cons #\" (nconc y (list #\")))))
-	   (t (setq y (cons #\? (slash y)))))
+       (t (setq y (cons #\? (slash y)))))
      (return (msz y l r))))
 
 (defun msz (x l r) (setq x (nreconc l (nconc x r))) (cons (length x) x))
