@@ -22,9 +22,9 @@
   (setq genvar (cons g genvar))
   (setq varlist (cons e varlist))
   (putprop g p 'unhacked)
-  g) 
+  g)
 
-(defun getunhack (gen) (or (get gen 'unhacked) (pget gen))) 
+(defun getunhack (gen) (or (get gen 'unhacked) (pget gen)))
 
 (defmacro getdis (x) `(get ,x 'disrep))
 
@@ -39,22 +39,22 @@
 		(cons 'b (cadddr l)))
 	  '(prog1 (car (setq a fncall)) (setq b (caddr a) a (cadr a)))))
 
-(defun pquocof (p q) 
+(defun pquocof (p q)
   (let ((qq (testdivide p q)))
     (cond (qq (list q qq 1))
-	  ((list 1 p q))))) 
+	  ((list 1 p q)))))
 
-(defun polyst (a) 
+(defun polyst (a)
   (cond ((pcoefp a) (list a))
-	(t (cons (cons (car a) (cadr a)) (polyst (caddr a)))))) 
+	(t (cons (cons (car a) (cadr a)) (polyst (caddr a))))))
 
-(defun cdinf (a b both) 
+(defun cdinf (a b both)
   (cond ((or (pcoefp a) (pcoefp b)) (list 1 a b))
 	(t (setq a (ncons (copy-tree a))
 		 b (ncons (cond (both (copy-tree b))(t b))))
-	   (list (cd1 a b both) (car a) (car b))))) 
+	   (list (cd1 a b both) (car a) (car b)))))
 
-(defun cd1 (a b both) 
+(defun cd1 (a b both)
   (cond ((or (pcoefp (car a)) (pcoefp (car b))) 1)
 	((eq (caar a) (caar b))
 	 (ptimes (pexpt (pget (caar a))	;CHECK FOR ALG. TRUNC.
@@ -64,9 +64,9 @@
 				(t (setq b (cddar b))))))
 		 (cd1 a b both)))
 	((pointergp (caar a) (caar b)) (cd1 (cddar a) b both))
-	(t (cd1 a (cddar b) both)))) 
+	(t (cd1 a (cddar b) both))))
 
-(defun lmake (p l) 
+(defun lmake (p l)
   (cond ((pcoefp p) (cons p l))
 	((get (car p) 'unhacked)
 	 (lmake (caddr p) (cons (cons (car p) (cadr p)) l)))
@@ -79,14 +79,14 @@
 	(cdr l))
   (cond ((equal (car l) 1) (cdr l))
 	(t (rplaca l (cons (car l) 1)))))
- 
 
-(defun pmake (l) 
+
+(defun pmake (l)
   (cond ((null l) 1)
 	((= 0 (cdar l)) (pmake (cdr l)))
 	((numberp (caar l))	     ;CLAUSE SHOULD BE ELIMINATED ASAP
 	 (ptimes (cexpt (caar l) (cdar l)) (pmake (cdr l))))
-	(t (ptimes (list (caar l) (cdar l) 1) (pmake (cdr l)))))) 
+	(t (ptimes (list (caar l) (cdar l) 1) (pmake (cdr l))))))
 
 (defun facmgcd (pl)            ;GCD OF POLY LIST FOR EZGCD WITH RATFAC
   (do ((l (cdr pl) (cdr l))
@@ -99,24 +99,24 @@
 	  ((not (equal (cadr gcd) 1))
 	   (do ((l2 ans (cdr l2))) ((null l2))
 	     (rplaca l2 (ptimes (cadr gcd) (car l2))))))))
-			     
+
 
 (defun fpgcdco (p q)
   (let ($ratfac gcdl)			;FACTORED PGCDCOFACTS
     (cond ((or (pcoefp p) (pcoefp q)) (pgcdcofacts p q))
-	  (t (list (ptimeschk 
+	  (t (list (ptimeschk
 		    (setcall pgcdcofacts p q)
 		    (car (setq p (lmake p nil)
 			       q (lmake q nil)
 			       gcdl (mapcar 'pmake (lgcd1 (cdr p) (cdr q)) ))))
 		   (ptimeschk (car p) (cadr gcdl))
-		   (ptimeschk (car q) (caddr gcdl))))))) 
+		   (ptimeschk (car q) (caddr gcdl)))))))
 
 ;;	NOTE: ITEMS ON VARLIST ARE POS. NORMAL
 ;;	INTEGER COEF GCD=1 AND LEADCOEF. IS POS.
 
-(defun lgcd1 (a b) 
-  (prog (ptlist g bj c t1 d1 d2) 
+(defun lgcd1 (a b)
+  (prog (ptlist g bj c t1 d1 d2)
      (setq ptlist (mapcar #'(lambda (ig) (declare (ignore ig)) b) a))
      (do ((a a (cdr a))
 	  (ptlist ptlist (cdr ptlist)))
@@ -162,7 +162,7 @@
 	 (and (equal bj 1) (rplacd (car b) 0))
 	 (and (equal ai 1) (rplacd (car a) 0) (return nil))
 	nextb))
-     (return (list g a b)))) 
+     (return (list g a b))))
 
 (defun makprodg (p sw)
   (cond ((pcoefp p) p)
@@ -173,28 +173,28 @@
 	 $gcd)( $ratfac nil)) (or (member $gcd *gcdl* :test #'eq) (setq $gcd '$ez))
 	 (pgcdcofacts x y)))
 
-(defun facrplus (x y) 
-  ((lambda (a b c d)
-     (setq x (setcall dopgcdcofacts a c) 
-	   y (setcall fpgcdco b d))
-     (setq a (makprod
-	      (pplus (pflatten (ptimeschk a d))
-		     (pflatten (ptimeschk b c))) nil))
-     (setq b (ptimeschk b d))
-     (cond ($algebraic (setq y (ptimeschk y b))
-		       (setcall fpgcdco y a) ;for unexpected gcd
-		       (cons (ptimes x a) y))
-	   (t (setq c (setcall cdinf y b nil))
-	      (setcall fpgcdco y a)
-	      (cons (ptimes x a) (ptimeschk y (ptimeschk c b))))))
-   (car x)
-   (cdr x)
-   (car y)
-   (cdr y)))
+(defun facrplus (x y)
+  (let ((a (car x))
+	(b (cdr x))
+	(c (car y))
+	(d (cdr y)))
+    (setq x (setcall dopgcdcofacts a c)
+	  y (setcall fpgcdco b d))
+    (setq a (makprod
+	     (pplus (pflatten (ptimeschk a d))
+		    (pflatten (ptimeschk b c))) nil))
+    (setq b (ptimeschk b d))
+    (cond ($algebraic (setq y (ptimeschk y b))
+		      (setcall fpgcdco y a) ;for unexpected gcd
+		      (cons (ptimes x a) y))
+	  (t (setq c (setcall cdinf y b nil))
+	     (setcall fpgcdco y a)
+	     (cons (ptimes x a) (ptimeschk y (ptimeschk c b)))))))
 
 (defun mfacpplus (l)
-  (let (($gcd
-	 (or $gcd '$ez))( $ratfac nil)( g nil))
+  (let (($gcd (or $gcd '$ez))
+	($ratfac nil)
+	(g nil))
     (setq g (oldcontent2 (sort (copy-list l) 'contodr) 0))
     (cond ((pzerop g) g)
 	  ((do ((a (pflatten (pquotient (car l) g))
@@ -202,7 +202,7 @@
 		(ll (cdr l) (cdr ll)))
 	       ((null ll) (ptimes g (makprod a nil))))))))
 
-(defun  facrtimes (x y gcdsw) 
+(defun  facrtimes (x y gcdsw)
   (cond ((not gcdsw)
 	 (cons (ptimes (car x) (car y)) (ptimeschk (cdr x) (cdr y))))
 	(t (let ((g (cdinf (car x) (car y) t))
@@ -221,15 +221,14 @@
   (let (($ratfac
 	 nil))				;algebraic uses
     (setq poly (oldcontent poly))	;rattimes?
-    ((lambda (a)			;main var. content
-       (cond ((> a 0) (setq a (list (caadr poly) a 1))
-	      (setq poly
-		    (list (ptimes (car poly) a)
-			  (pquotient (cadr poly) a))))))
-     (lowdeg (cdadr poly)))
-    (cond ((pminusp (cadr poly))
-	   (list (pminus (car poly)) (pminus (cadr poly))))
-	  (t poly))))
+    (let ((a (lowdeg (cdadr poly))))	;main var. content
+      (cond ((> a 0) (setq a (list (caadr poly) a 1))
+	     (setq poly
+		   (list (ptimes (car poly) a)
+			 (pquotient (cadr poly) a))))))
+    (if (pminusp (cadr poly))
+	(list (pminus (car poly)) (pminus (cadr poly)))
+	poly)))
 
 ;; LOWDEG written to compute the lowest degree of a polynomial. - RZ
 
@@ -237,42 +236,42 @@
   (do ((l p (cddr l)))
       ((null (cddr l)) (car l))))
 
-(defun makprod (poly contswitch) 
+(defun makprod (poly contswitch)
   (cond ((pureprod poly) poly)
 	((null (cdddr poly))
 	 (ptimes (list (car poly) (cadr poly) 1)
 		 (makprod (caddr poly) contswitch)))
 	(contswitch (makprod1 poly))
 	(t (setq poly (fpcontent poly))
-	   (ptimes (makprod (car poly) contswitch) (makprod1 (cadr poly)))))) 
+	   (ptimes (makprod (car poly) contswitch) (makprod1 (cadr poly))))))
 
-(defun makprod1 (poly*) 
+(defun makprod1 (poly*)
   (do ((v varlist (cdr v))
        (g genvar (cdr g))
        (p (pdis poly*))
        (res 1))
       ((null v) (maksymp poly*))
-    (and (alike1 p (car v)) (return (pget (car g)))))) 
+    (and (alike1 p (car v)) (return (pget (car g))))))
 
 (defun maksym (p)
-  (newsym2 p (pdis p))) 
+  (newsym2 p (pdis p)))
 
 (defun maksymp (p)
   (cond ((atom p) p)
-	(t (pget (maksym p))))) 
+	(t (pget (maksym p)))))
 
-(defun pflatten (h) 
-  (prog (m) 
+(defun pflatten (h)
+  (prog (m)
      (setq m (listovars h))
      checkmore
      (cond ((null m) (return h))
-	   ((not ((lambda (p) (or (null p) (eq (car m) (car p))))
-		  (getunhack (car m))))
+	   ((not (let ((p (getunhack (car m))))
+		   (or (null p) (eq (car m) (car p)))))
 	    (go redo))
 	   (t (setq m (cdr m)) (go checkmore)))
-     redo (return (let ($ratfac) (pflat1 h))))) 
+     redo (return (let ($ratfac) (pflat1 h)))))
 
-(defun pflat1 (p) 
+(defun pflat1 (p)
   (cond ((pcoefp p) p)
 	((null (cdddr p))
 	 (ptimes (pexpt (getunhack (car p)) (cadr p)) (pflat1 (caddr p))))
@@ -286,12 +285,12 @@
 				  (pexpt val (- ld (car a))))
 			  (pflat1 (cadr a))))))))
 
-(defun pirredp (x) 
+(defun pirredp (x)
   (and (setq x (getdis x))
        (or (atom x) (member 'irreducible (cdar x) :test #'eq))))
 
-(defun knownfactors (d) 
-  (prog (h) 
+(defun knownfactors (d)
+  (prog (h)
      (cond ((pcoefp d) (return d)))
      (setq h (getdis (car d)))
      (return (cond ((or (atom h) (not (eq (caar h) 'mtimes)))
@@ -299,4 +298,4 @@
 			    (list (car d) (cadr d) 1)))
 		   (t (setq h (getunhack (car d)))
 		      (ptimes (knownfactors (caddr d))
-			      (pexpt (knownfactors h) (cadr d)))))))) 
+			      (pexpt (knownfactors h) (cadr d))))))))
