@@ -41,7 +41,7 @@
 (defun consrule (x)
   (let ((rule (mget x '$rule)))
     (if rule (list '(msetq simp) x (cons '(marrow simp) (cdr rule)))
-	(merror "~:M not a user rule" x))))
+	(merror (intl:gettext "disprule: ~:M is not a user rule.") x))))
 
 (defmfun $remrule (op rule) 
   (prog (rules) 
@@ -49,7 +49,7 @@
      (cond ((not (eq rule '$all))
 	    (removerule op rule) (return (getop op)))
 	   ((null (setq rules (mget op 'oldrules)))
-	    (merror "~:@M has no rules" op)))
+	    (merror (intl:gettext "remrule: no rules known for operator ~:@M") op)))
      next (cond ((or (null rules) (null (cdr rules)))
 		 (mputprop op 1 'rulenum) (return (getop op)))
 		(t (removerule op (car rules))
@@ -63,7 +63,7 @@
 	     (oldrules old othrulename othrule)
 	    (setq oldrules (mget op 'oldrules))
 	    (cond ((or (null rule) (null (setq oldrules (member rule oldrules :test #'equal))))
-		   (merror "~:M - no such rule." rule))
+		   (merror (intl:gettext "remrule: no such rule: ~:M") rule))
 		  ((null (car (setq oldrules (cdr oldrules))))
 		   (setq oldrules (cdr oldrules))
 		   (setq othrulename 'simpargs1)
@@ -147,15 +147,16 @@
 
 (defmfun part+ (e p preds) 
   (prog (flag saved val) 
+     (if (not (mplusp e)) (matcherr))
      (cond ((> (length p) (length preds))
 	    (setq p (reverse p))
 	    (setq p (nthkdr p (- (length p) (length preds))))
 	    (setq p (nreverse p))))
      (setq e (copy-tree e)) ; PREVIOUSLY: (setq e ($ratexpand e))
-     (setq e (cond ((not (mplusp e)) (ncons e)) (t (cdr e))))
+     (setq e (cdr e))
      a    (cond ((null p) (cond ((null e) (return t)) (t (matcherr))))
 		((and (cdr preds) (member (car (caddar preds)) '(msetq setq) :test #'eq))
-		 (cond (flag (merror "Two or more pattern variables `true'"))
+		 (cond (flag (merror (intl:gettext "PART+: two or more pattern variables match anything.")))
 		       (t (setq flag t p (reverse p) preds (reverse preds))
 			  (go a))))
 		(t (mset (car p) 0)))
@@ -175,15 +176,16 @@
 
 (defmfun part* (e p preds) 
   (prog (flag saved val $factorflag) 
+     (if (not (mtimesp e)) (matcherr))
      (cond ((> (length p) (length preds))
 	    (setq p (reverse p))
 	    (setq p (nthkdr p (- (length p) (length preds))))
 	    (setq p (nreverse p))))
      (setq e (copy-tree e)) ; PREVIOUSLY: (setq e ($factor e))
-     (setq e (cond ((not (mtimesp e)) (ncons e)) (t (cdr e))))
+     (setq e (cdr e))
      a    (cond ((null p) (cond ((null e) (return t)) (t (matcherr))))
 		((and (cdr preds) (member (car (caddar preds)) '(msetq setq) :test #'eq))
-		 (cond (flag (merror "Two or more pattern variables `true'"))
+		 (cond (flag (merror (intl:gettext "PART*: two or more pattern variables match anything.")))
 		       (t (setq flag t p (reverse p) preds (reverse preds))
 			  (go a))))
 		((not (atom (car p)))
@@ -262,7 +264,7 @@
 
 (defun *rulechk (*rule)
   (if (and (symbolp *rule) (not (fboundp *rule)) (not (mfboundp *rule)))
-      (merror "~:M not found" *rule)))
+      (merror (intl:gettext "apply1: no such rule: ~:M") *rule)))
 
 (defun rule-apply (*rule expr)
   (prog (ans rule-hit)
