@@ -275,7 +275,7 @@
 			 ((mlist) $grid 30 30)
 			 ((mlist) $transform_xy nil)
 			 ((mlist) $run_viewer t)
-			 ((mlist) $plot_format $openmath)
+			 ((mlist) $plot_format $xmaxima)
 			 ((mlist) $nticks 100)
 			 ))
 
@@ -324,3 +324,6 @@
     $orbits
     $rk))
   ($auto_mexpr mexpr "dynamics"))
+
+(defprop $hypergeometric simp-hypergeometric operators)
+(autof 'simp-hypergeometric "hypergeometric")
\ No newline at end of file
