@@ -15,7 +15,7 @@
 (defmfun $sort (l &optional (f 'lessthan))
   (let ((llist l) comparfun bfun)
     (unless ($listp llist)
-      (merror "The first argument to `sort' must be a list:~%~M" llist))
+      (merror (intl:gettext "sort: first argument must be a list; found: ~M") llist))
     (setq llist (copy-list (cdr llist))
 	  comparfun 
 	  (mfunction1 (setq bfun (getopr f))))
@@ -27,10 +27,12 @@
 ;; closure version.  Gcl likes either...  For the moment we will
 ;; leave a conditional here.
 (defun mfunction1 (fun)
-  #+(or cmu scl)
-  (lambda (x y) (mevalp `((,fun) ((mquote) ,x) ((mquote) ,y))))
-  #-(or cmu scl)
-  #'(lambda (x y) (mevalp `((,fun) ((mquote) ,x) ((mquote) ,y)))))
+  (if (functionp fun)
+      fun
+      #+(or cmu scl)
+      (lambda (x y) (mevalp `((,fun) ((mquote) ,x) ((mquote) ,y))))
+      #-(or cmu scl)
+      #'(lambda (x y) (mevalp `((,fun) ((mquote) ,x) ((mquote) ,y))))))
 
 (defun lessthan (a b)
   (great b a))
@@ -40,20 +42,18 @@
   (prog (n form arg a b lv d)
      (setq n (length x))
      (if (or (< n 3) (> n 4))
-	 (merror "`makelist' takes 3 or 4 arguments."))
+	 (merror (intl:gettext "makelist: must have 3 or 4 arguments.")))
      (setq form (car x)
 	   arg (cadr x)
 	   a (meval (caddr x))
 	   lv (cond ((= n 3) 
 		     (if ($listp a)
 			 (mapcar #'(lambda (u) (list '(mquote) u)) (cdr a))
-			 (merror "If 3 arguments are given to MAKELIST, ~
-the 3rd argument should evaluate to a list:~%~M" a)))
+			 (merror (intl:gettext "makelist: third argument must evaluate to a list; found: ~M") a)))
 		    (t
 		     (setq b (meval (cadddr x)))
 		     (if (or (not (integerp (setq d (sub* b a)))) (< d -1))
-			 (merror "If 4 arguments are given to MAKELIST, the difference of the 3rd ~
-and 4th arguments should evaluate to a non-negative integer:~%~M" d)
+			 (merror (intl:gettext "makelist: fourth argument minus third must be a nonnegative integer; found: ~M") d)
 			 (interval a b)))))
      (return 
        (do ((lv lv (cdr lv))
@@ -74,7 +74,7 @@ and 4th arguments should evaluate to a non-negative integer:~%~M" d)
 
 (defmfun $sublist (a f)
   (unless ($listp a)
-    (merror "The first argument to `sublist' must be a list:~%~M" a) )
+    (merror (intl:gettext "sublist: first argument must be a list; found: ~M") a) )
   (do ((a (cdr a) (cdr a))
        (x))
       ((null a) (cons '(mlist simp) (nreverse x)))
