@@ -14,7 +14,7 @@
 
 (load-macsyma-macros defcal mopers)
 
-(defmvar *alphabet* '(#\_ #\%))
+(defmvar *alphabet* (list #\_ #\%))
 
 (defmfun alphabetp (n)
   (and (characterp n)
@@ -42,7 +42,7 @@
        (setq file  (namestring *parse-stream*)))
       (when tem
 	(format t "~%~a:~a:" file tem))
-      (format t "Incorrect syntax: ")
+      (format t (intl:gettext "incorrect syntax: "))
       (apply 'format t format-string (mapcar #'(lambda (x)
 						 (if (symbolp x)
 						     (print-invert-case x)
@@ -240,7 +240,7 @@
 (defun scan-token (flag)
   (do ((c (parse-tyipeek) (parse-tyipeek))
        (l () (cons c l)))
-      ((and flag (not (or (digit-char-p c) (alphabetp c) (char= c #\\))))
+      ((and flag (not (or (digit-char-p c (max 10. *read-base*)) (alphabetp c) (char= c #\\))))
        (nreverse (or l (ncons (parse-tyi))))) ; Read at least one char ...
     (when (char= (parse-tyi) #\\)
       (setq c (parse-tyi)))
@@ -266,6 +266,55 @@
 (defun readlist (lis)
   (read-from-string (coerce lis 'string)))
 
+;; These variables control how we convert bfloat inputs to the
+;; internal bfloat representation.  These variables should probably go
+;; away after some testing.
+(defmvar $fast_bfloat_conversion t
+  "Use fast, but possibly inaccurate conversion")
+(defmvar $fast_bfloat_threshold 100000.
+  "Exponents larger than this (in absolute value) will use the fast
+  conversion instead of the accurate conversion")
+(defvar *fast-bfloat-extra-bits* 0)
+
+;; Here is a test routine to test the fast bfloat conversion
+#+nil
+(defun test-make-number (&optional (n 1000))
+  (let ((failures 0))
+    (dotimes (k n)
+      (flet ((digit-list (n)
+	       (coerce (format nil "~D" n) 'list)))
+	(let ((numlist nil))
+	  ;; Generate a random number with 30 fraction digits and an
+	  ;; large exponent.
+	  (push (digit-list (random 10)) numlist)
+	  (push '(#\.) numlist)
+	  (push (digit-list (random (expt 10 30))) numlist)
+	  (push '(#\B) numlist)
+	  (push (if (zerop (random 2)) '(#\+) '(#\-)) numlist)
+	  (push (digit-list (+ $fast_bfloat_threshold
+			       (random $fast_bfloat_threshold)))
+		numlist)
+	  ;; Convert using accurate and fast methods and compare the
+	  ;; results.
+	  (let ((true (let (($fast_bfloat_conversion nil))
+			(make-number (copy-list numlist))))
+		(fast (let (($fast_bfloat_conversion t))
+			(make-number (copy-list numlist)))))
+	    (format t "Test ~3A: " k)
+	    (map nil #'(lambda (x)
+			 (map nil #'princ x))
+		 (reverse numlist))
+	    (terpri)
+	    (unless (equalp true fast)
+	      (incf failures)
+	      (format t "NUM:  ~A~%  TRUE: ~S~%  FAST: ~S~%"
+		      (reverse numlist) true fast))))))
+    (format t "~D failures in ~D tests (~F%)~%"
+	    failures n (* 100 failures (/ (float n))))))
+
+
+;; WARNING: MAKE-NUMBER destructively modifies it argument!  Should we
+;; change that?
 (defun make-number (data)
   (setq data (nreverse data))
   ;; Maxima really wants to read in any number as a flonum
@@ -273,19 +322,52 @@
   ;; markers to the flonum-exponent-marker.
   (let ((marker (car (nth 3 data))))
     (unless (eql marker flonum-exponent-marker)
-      (when (member marker '(#\E #\S #\D #\L #+cmu #\W))
+      (when (member marker '(#\E #\F #\S #\D #\L #+cmu #\W))
         (setf (nth 3 data) (list flonum-exponent-marker)))))
   (if (not (equal (nth 3 data) '(#\B)))
       (readlist (apply #'append data))
-      ;; For bigfloats, turn them into rational numbers then convert to bigfloat.
-      ;; Fix for the 0.25b0 # 2.5b-1 bug.  Richard J. Fateman posted this fix to the
-      ;; Maxima list on 10 October 2005.  Without this fix, some tests in rtestrationalize
-      ;; will fail.  Used with permission.
-      ($bfloat (simplifya `((mtimes) ((mplus) ,(readlist (or (first data) '(#\0)))
-				    ((mtimes) ,(readlist (or (third data) '(#\0)))
-				     ((mexpt) 10. ,(- (length (third data))))))
-			  ((mexpt) 10. ,(funcall (if (char= (first (fifth data)) #\-) #'- #'+)
-						 (readlist (sixth data))))) nil))))
+      (let ((int-part (readlist (or (first data) '(#\0))))
+	    (frac-part (readlist (or (third data) '(#\0))))
+	    (frac-len (length (third data)))
+	    (exp-sign (first (fifth data)))
+	    (exp (readlist (sixth data))))
+	(if (and $fast_bfloat_conversion
+		 (> (abs exp) $fast_bfloat_threshold))
+	    ;; Exponent is large enough that we don't want to do exact
+	    ;; rational arithmetic.  Instead we do bfloat arithmetic.
+	    ;; For example, 1.234b1000 is converted by computing
+	    ;; bfloat(1234)*10b0^(1000-3).  Extra precision is used
+	    ;; during the bfloat computations.
+	    (let* ((extra-prec (+ *fast-bfloat-extra-bits* (ceiling (log exp 2d0))))
+		   (fpprec (+ fpprec extra-prec))
+		   (mant (+ (* int-part (expt 10 frac-len)) frac-part))
+		   (bf-mant (bcons (intofp mant)))
+		   (p (power (bcons (intofp 10))
+			     (- (if (char= exp-sign #\-)
+				    (- exp)
+				    exp)
+				frac-len)))
+		   ;; Compute the product using extra precision.  This
+		   ;; helps to get the last bit correct (but not
+		   ;; always).  If we didn't do this, then bf-mant and
+		   ;; p would be rounded to the target precision and
+		   ;; then the product is rounded again.  Doing it
+		   ;; this way, we still have 3 roundings, but bf-mant
+		   ;; and p aren't rounded too soon.
+		   (result (mul bf-mant p)))
+	      (let ((fpprec (- fpprec extra-prec)))
+		;; Now round the product back to the desired precision.
+		(bigfloatp result)))
+	    ;; For bigfloats, turn them into rational numbers then
+	    ;; convert to bigfloat.  Fix for the 0.25b0 # 2.5b-1 bug.
+	    ;; Richard J. Fateman posted this fix to the Maxima list
+	    ;; on 10 October 2005.  Without this fix, some tests in
+	    ;; rtestrationalize will fail.  Used with permission.
+	    (let ((ratio (* (+ int-part (* frac-part (expt 10 (- frac-len))))
+			    (expt 10 (if (char= exp-sign #\-)
+					 (- exp)
+					 exp)))))
+	    ($bfloat (cl-rat-to-maxima ratio)))))))
 
 ;; Richard J. Fateman wrote the big float to rational code and the function
 ;; cl-rat-to-maxmia.
@@ -298,7 +380,7 @@
 (defun scan-digits (data continuation? continuation &optional exponent-p)
   (do ((c (parse-tyipeek) (parse-tyipeek))
        (l () (cons c l)))
-      ((not (and (characterp c) (digit-char-p c)))
+      ((not (and (characterp c) (digit-char-p c (max 10. *read-base*))))
        (cond ((member c continuation?)
 	      (funcall continuation (list* (ncons (char-upcase
 						   (parse-tyi)))
@@ -308,13 +390,13 @@
 	      ;; We're trying to parse the exponent part of a number,
 	      ;; and we didn't get a value after the exponent marker.
 	      ;; That's an error.
-	      (merror "Incomplete number.  Missing exponent?"))
+	      (merror (intl:gettext "parser: incomplete number; missing exponent?")))
 	     (t
 	      (make-number (cons (nreverse l) data)))))
     (parse-tyi)))
 
 (defun scan-number-after-dot (data)
-  (scan-digits data '(#\E #\e #\B #\b #\D #\d #\S #\s) #'scan-number-exponent))
+  (scan-digits data '(#\E #\e #\F #\f #\B #\b #\D #\d #\S #\s) #'scan-number-exponent))
 
 (defun scan-number-exponent (data)
   (push (ncons (if (or (char= (parse-tyipeek) #\+)
@@ -417,7 +499,7 @@
 	   (cond  ((eql test -1.)
 		   (parse-tyi)
 		   (if eof-ok? eof-obj
-		       (maxima-error "End of file while scanning expression")))
+		       (maxima-error (intl:gettext "parser: end of file while scanning expression."))))
 		  ((eql test #\/)
 		   (parse-tyi)
 		   (cond ((char= (parse-tyipeek) #\*)
@@ -425,7 +507,7 @@
 			  (scan-one-token-g eof-ok? eof-obj))
 			 (t '$/)))
 		  ((eql test #\.) (parse-tyi)	; Read the dot
-		   (if (digit-char-p (parse-tyipeek))
+		   (if (digit-char-p (parse-tyipeek) 10.)
 		       (scan-number-after-dot (list (ncons #\.) nil))
 		       '|$.|))
 		  ((eql test #\")
@@ -441,7 +523,7 @@
 			 (t
 			  (scan-lisp-token))))
 		  (t
-		   (if (digit-char-p test)
+		   (if (digit-char-p test 10.)
 		       (scan-number-before-dot ())
 		       (scan-macsyma-token))))))))
 
@@ -453,7 +535,7 @@
 	(setq c (parse-tyipeek))
 	(parse-tyi)
 	(cond ((= depth 0) (return t)))
-	(cond ((and (numberp c) (< c 0))(error "end of file in comment"))
+	(cond ((and (numberp c) (< c 0))(error (intl:gettext "parser: end of file in comment.")))
 	      ((char= c #\*)
 	       (cond ((char= (parse-tyipeek) #\/)
 		      (decf depth)
@@ -472,7 +554,7 @@
     (cond ((member c '(#\.))
 	   ;; We found a dot
 	   (scan-number-after-dot data))
-	  ((member c '(#\E #\e #\B #\b #\D #\d #\S #\s))
+	  ((member c '(#\E #\e #\F #\f #\B #\b #\D #\d #\S #\s))
 	   ;; Dot missing but found exponent marker.  Fake it.
 	   (setf data (push (ncons #\.) (rest data)))
 	   (push (ncons #\0) data)
@@ -480,7 +562,7 @@
 	   (scan-number-exponent data)))))
 
 (defun scan-number-before-dot (data)
-  (scan-digits data '(#\. #\E #\e #\B #\b #\D #\d #\S #\s)
+  (scan-digits data '(#\. #\E #\e #\F #\f #\B #\b #\D #\d #\S #\s)
 	       #'scan-number-rest))
 
 
@@ -489,7 +571,7 @@
 (defmacro first-c () '(peek-one-token))
 (defmacro pop-c   () '(scan-one-token))
 
-(defun mstringp (x) (stringp x))
+(defun mstringp (x) (stringp x)) ;; OBSOLETE. PRESERVE FOR SAKE OF POSSIBLE CALLS FROM NON-MAXIMA CODE !!
 
 (defun inherit-propl (op-to op-from getl)
   (let ((propl (getl op-from getl)))
@@ -1189,7 +1271,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 
 (def-nud-equiv	|$+| parse-prefix)
 (def-lbp	|$+| 100.)
-(def-rbp	|$+| 100.)
+(def-rbp	|$+| 134.) ; Value increased from 100 to 134 (DK 02/2010).
 (def-pos	|$+| $expr)
 (def-rpos	|$+| $expr)
 ;LPOS not needed
@@ -1524,7 +1606,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
   (let ((x))
     (if (or (and rbp (not (integerp (setq x rbp))))
 	    (and lbp (not (integerp (setq x lbp)))))
-	(merror "Binding powers must be integers.~%~M is not an integer." x))
+	(merror (intl:gettext "syntax extension: binding powers must be integers; found: ~M") x))
     (if (stringp op) (setq op (define-symbol op)))
     (op-setup op)
     (let ((noun   ($nounify op))
