@@ -19,12 +19,27 @@
 (defmfun simp-%sinh (form y z) 
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((big-float-eval (mop form) y))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) 0)))
 	((and $%iargs (multiplep y '$%i)) (mul '$%i (cons-exp '%sin (coeff y '$%i 1))))
-	((and $triginverses (not (atom y)) (if (eq '%asinh (caar y)) (cadr y))))
+	((and $triginverses (not (atom y))
+	      (let ((fcn (caar y))
+		    (arg (cadr y)))
+		(cond ((eq '%asinh fcn)
+		       arg)
+		      ((eq '%acosh fcn)
+		       ;; ratsimp(logarc(exponentialize(sinh(acosh(x))))),algebraic;
+		       ;; -> sqrt(x-1)*sqrt(x+1)
+		       (mul (power (sub arg 1) 1//2)
+			    (power (add arg 1) 1//2)))
+		      ((eq '%atanh fcn)
+		       ;; radcan(logarc(exponentialize(sinh(atanh(x)))));
+		       ;; -> x/(sqrt(1-x)*sqrt(1+x))
+		       (div arg
+			    (mul (power (sub 1 arg) 1//2)
+				 (power (add 1 arg) 1//2))))))))
 	((and $trigexpand (trigexpand '%sinh y)))
 	($exponentialize (exponentialize '%sinh y))
 	((and $halfangles (halfangle '%sinh y)))
@@ -35,12 +50,30 @@
 (defmfun simp-%cosh (form y z) 
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) 1)))
 	((and $%iargs (multiplep y '$%i)) (cons-exp '%cos (coeff y '$%i 1)))
-	((and $triginverses (not (atom y)) (if (eq '%acosh (caar y)) (cadr y))))
+	((and $triginverses (not (atom y))
+	      (let ((fcn (caar y))
+		    (arg (cadr y)))
+		(cond ((eq '%acosh fcn)
+		       arg)
+		      ((eq '%asinh fcn)
+		       ;; ex: cosh(asinh(x));
+		       ;; ex,exponentialize,logarc;
+		       ;; ratsimp(%),algebraic
+		       ;; -> sqrt(x^2+1)
+		       ;; 
+		       (sqrt1+x^2 arg))
+		      ((eq '%atanh fcn)
+		       ;; ex: cosh(atanh(x))
+		       ;; radcan(logarc(exponentialize(ex)))
+		       ;; -> 1/sqrt(1-x)/sqrt(1+x)
+		       (div 1
+			    (mul (power (sub 1 arg) 1//2)
+				 (power (add 1 arg) 1//2))))))))
 	((and $trigexpand (trigexpand '%cosh y)))
 	($exponentialize (exponentialize '%cosh y))
 	((and $halfangles (halfangle '%cosh y)))
@@ -51,12 +84,26 @@
 (defmfun simp-%tanh (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) 0)))
 	((and $%iargs (multiplep y '$%i)) (mul '$%i (cons-exp '%tan (coeff y '$%i 1))))
-	((and $triginverses (not (atom y)) (if (eq '%atanh (setq z (caar y))) (cadr y))))
+	((and $triginverses (not (atom y))
+	      (let ((fcn (caar y))
+		    (arg (cadr y)))
+		(cond ((eq '%atanh fcn)
+		       arg)
+		      ((eq '%asinh fcn)
+		       ;; ratsimp(logarc(exponentialize(tanh(asinh(x))))),algebraic;
+		       ;; --> x/sqrt(1+x^2)
+		       (div arg (sqrt1+x^2 arg)))
+		      ((eq '%acosh fcn)
+		       ;; ratsimp(logarc(exponentialize(tanh(acosh(x))))),algebraic;
+		       ;; sqrt(x-1)*sqrt(x+1)/x
+		       (div (mul (power (sub arg 1) 1//2)
+				 (power (add arg 1) 1//2))
+			    arg))))))
 	((and $trigexpand (trigexpand '%tanh y)))
 	($exponentialize (exponentialize '%tanh y))
 	((and $halfangles (halfangle '%tanh y)))
@@ -67,7 +114,7 @@
 (defmfun simp-%coth (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) (domain-error y 'coth))))
@@ -83,7 +130,7 @@
 (defmfun simp-%csch (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (cond ((zerop1 y) (domain-error y 'csch)))))
@@ -99,7 +146,7 @@
 (defmfun simp-%sech (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (zerop1 y)) 1)
@@ -115,7 +162,7 @@
 (defmfun simp-%asin (form y z) 
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs
@@ -140,7 +187,20 @@
 		    ((alike1 y (div (power* 3 1//2) -2))
 		     (div '$%pi -3)))))
 	((and $%iargs (multiplep y '$%i)) (mul '$%i (cons-exp '%asinh (coeff y '$%i 1))))
-	((and (eq $triginverses '$all) (not (atom y)) (if (eq '%sin (caar y)) (cadr y))))
+	((and (not (atom y)) (member (caar y) '(%cos %sin))
+	      (if ($constantp (cadr y))
+		  (let ((y-val (mfuncall '$mod
+					 (if (eq (caar y) '%sin) (cadr y) (m- %pi//2 (cadr y)))
+					 (m* 2 '$%pi))))
+		    (cond ((eq (mlsp y-val %pi//2) t) y-val)
+			  ((eq (mlsp y-val (m* 3 %pi//2)) t) (m- '$%pi y-val))
+			  ((eq (mlsp y-val (m* 2 '$%pi)) t) (m- y-val (m* 2 '$%pi))))))))
+	((and (eq $triginverses t) (not (atom y)) (eq (caar y) '%sin)
+	      (if (and (member (csign (m- (cadr y) %pi//2)) '($nz $neg) :test #'eq)
+		       (member (csign (m+ (cadr y) %pi//2)) '($pz $pos) :test #'eq))
+		  (cadr y))))
+	((and (eq $triginverses '$all) (not (atom y))
+	      (if (eq '%sin (caar y)) (cadr y))))
 	($logarc (logarc '%asin y))
 	((apply-reflection-simp (mop form) y $trigsign))
 	;((and $trigsign (mminusp* y)) (neg (cons-exp '%asin (neg y))))
@@ -149,7 +209,7 @@
 (defmfun simp-%acos (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs 
@@ -164,7 +224,7 @@
 		     (mul '((rat simp) 1 3) '$%pi))
 		    ((alike1 y -1//2)
 		     (mul '$%pi (div 2 3)))
-		    ;; 1/sqrt(2)
+	    ;; 1/sqrt(2)
 		    ((alike1 y (power* 2 -1//2))
 		     (div '$%pi 4))
 		    ;; sqrt(3)/2
@@ -173,8 +233,19 @@
 		    ;; -sqrt(3)/2
 		    ((alike1 y (div (power* 3 1//2) -2))
 		     (mul '$%pi (div 5 6))))))
+	((and (not (atom y)) (member (caar y) '(%cos %sin))
+	      (if ($constantp (cadr y))
+		  (let ((y-val (mfuncall '$mod
+					 (if (eq (caar y) '%cos) (cadr y) (m- %pi//2 (cadr y)))
+					 (m* 2 '$%pi))))
+		    (cond ((eq (mlsp y-val '$%pi) t) y-val)
+			  ((eq (mlsp y-val (m* 2 '$%pi)) t) (m- (m* 2 '$%pi) y-val)))))))
 	((and (eq $triginverses '$all) (not (atom y))
 	      (if (eq '%cos (caar y)) (cadr y))))
+	((and (eq $triginverses t) (not (atom y)) (eq (caar y) '%sin)
+	      (if (and (member (csign (m- (cadr y) '$%pi)) '($nz $neg) :test #'eq)
+		       (member (csign (cadr y)) '($pz $pos) :test #'eq))
+		  (cadr y))))
 	($logarc (logarc '%acos y))
 	((apply-reflection-simp (mop form) y $trigsign))
 	;((and $trigsign (mminusp* y)) (sub '$%pi (cons-exp '%acos (neg y))))
@@ -183,14 +254,25 @@
 (defmfun simp-%acot (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs
 	      (cond ((zerop1 y) %pi//2) ((equal 1 y) %pi//4) ((equal -1 y) (neg %pi//4)))))
 	((and $%iargs (multiplep y '$%i)) (mul -1 '$%i (cons-exp '%acoth (coeff y '$%i 1))))
+	((and (not (atom y)) (member (caar y) '(%cot %tan))
+	      (if ($constantp (cadr y))
+		  (let ((y-val (mfuncall '$mod
+					 (if (eq (caar y) '%cot) (cadr y) (m- %pi//2 (cadr y)))
+					 '$%pi)))
+		    (cond ((eq (mlsp y-val %pi//2) t) y-val)
+			  ((eq (mlsp y-val '$%pi) t) (m- y-val '$%pi)))))))
 	((and (eq $triginverses '$all) (not (atom y))
 	      (if (eq '%cot (caar y)) (cadr y))))
+	((and (eq $triginverses t) (not (atom y)) (eq (caar y) '%cot)
+	      (if (and (member (csign (m- (cadr y) %pi//2)) '($nz $neg) :test #'eq)
+		       (member (csign (m+ (cadr y) %pi//2)) '($pz $pos) :test #'eq))
+		  (cadr y))))
 	($logarc (logarc '%acot y))
 	((apply-reflection-simp (mop form) y $trigsign))
 	;((and $trigsign (mminusp* y)) (neg (cons-exp '%acot (neg y))))
@@ -199,12 +281,18 @@
 (defmfun simp-%acsc (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs
 	      (cond ((equal 1 y) %pi//2) ((equal -1 y) (neg %pi//2)))))
 	((and $%iargs (multiplep y '$%i)) (mul -1 '$%i (cons-exp '%acsch (coeff y '$%i 1))))
+	((and (not (atom y)) (eq '%csc (caar y))
+	      (if ($constantp (cadr y))
+		  (let ((y-val (mfuncall '$mod (cadr y) (m* 2 '$%pi))))
+		    (cond ((eq (mlsp y-val %pi//2) t) y-val)
+			  ((eq (mlsp y-val (m* 3 %pi//2)) t) (m- '$%pi y-val))
+			  ((eq (mlsp y-val (m* 2 '$%pi)) t) (m- y-val (m* 2 '$%pi))))))))
 	((and (eq $triginverses '$all) (not (atom y))
 	      (if (eq '%csc (caar y)) (cadr y))))
 	($logarc (logarc '%acsc y))
@@ -215,11 +303,16 @@
 (defmfun simp-%asec (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs 
 	      (cond ((equal 1 y) 0) ((equal -1 y) '$%pi))))
+	((and (not (atom y)) (eq '%sec (caar y))
+	      (if ($constantp (cadr y))
+		  (let ((y-val (mfuncall '$mod (cadr y) (m* 2 '$%pi))))
+		    (cond ((eq (mlsp y-val '$%pi) t) y-val)
+			  ((eq (mlsp y-val (m* 2 '$%pi)) t) (m- (m* 2 '$%pi) y-val)))))))
 	((and (eq $triginverses '$all) (not (atom y))
 	      (if (eq '%sec (caar y)) (cadr y))))
 	($logarc (logarc '%asec y))
@@ -230,7 +323,7 @@
 (defmfun simp-%asinh (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) y)))
@@ -245,7 +338,7 @@
 (defmfun simp-%acosh (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (equal y 1) 0)))
@@ -257,7 +350,7 @@
 (defmfun simp-%atanh (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (cond ((zerop1 y) 0)
@@ -273,7 +366,7 @@
 (defmfun simp-%acoth (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (or (equal y 1) (equal y -1)) (domain-error y 'acoth))))
@@ -288,7 +381,7 @@
 (defmfun simp-%acsch (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (if (zerop1 y) (domain-error y 'acsch))))
@@ -303,7 +396,7 @@
 (defmfun simp-%asech (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
-  (cond ((double-float-eval (mop form) y))
+  (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
 	((and $%piargs (cond ((equal y 1) 0)
@@ -412,7 +505,7 @@
 	     (t num)))
     (setq num (cons (mul binom (power f i)) num) 
 	  den (cond ((= end i) den)
-		    (t (cons (mul (setq binom (// (* flag (- end i) binom) (1+ i)))
+		    (t (cons (mul (setq binom (truncate (* flag (- end i) binom) (1+ i)))
 				  (power f (1+ i)))
 			     den))))))
 
@@ -422,13 +515,13 @@
        (end (abs n))
        (num)
        (den)
-       (binom 1 (// (* flag (1- i) binom) (- end i -2))))
+       (binom 1 (truncate (* flag (1- i) binom) (- end i -2))))
       ((< i 0) (setq num (div* (cons '(mplus) num) (cons '(mplus) den)))
        (if (minusp n) (neg num) num))
     (setq num (cons (mul binom (power f i)) num)
 	  den (if (= 0 i)
 		  den
-		  (cons (mul (setq binom (// (* i binom) (- end i -1))) (power f (1- i))) den)))))
+		  (cons (mul (setq binom (truncate (* i binom) (- end i -1))) (power f (1- i))) den)))))
 
 (defun csc/sec-times (l m n f1 f2 flag)
   (div* (mul (power (cons-exp f1 (cons '(mtimes) l)) (abs n))
